@@ -85,7 +85,7 @@ class ArbitraryIntervals:
         self,
         *,
         absolute: builtins.bool,
-        intervals: typing.List["ScalingInterval"],
+        intervals: typing.Sequence["ScalingInterval"],
     ) -> None:
         '''
         :param absolute: 
